﻿#region License Information
/* HeuristicLab
 * Copyright (C) Heuristic and Evolutionary Algorithms Laboratory (HEAL)
 *
 * This file is part of HeuristicLab.
 *
 * HeuristicLab is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * HeuristicLab is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with HeuristicLab. If not, see <http://www.gnu.org/licenses/>.
 */
#endregion


using System.Linq;

namespace HeuristicLab.Problems.Instances.DataAnalysis {
  public class GasFlowModulation : ResourceRegressionDataDescriptor {

    public GasFlowModulation()
    : base("GasFlowModulation.csv") { }

    public override string Name { get { return "Gas Flow Modulation"; } }
    public override string Description { get { return "The data set contains 58 time series acquired from 16 chemical sensors under gas flow modulation conditions. The sensors were exposed to different gaseous binary mixtures of acetone and ethanol."; } }
    protected override string TargetVariable { get { return "ace_conc"; } }  // or  "eth_conc"
    protected override string[] VariableNames {
      get { return new[] { "exp", "batch", "ace_conc", "eth_conc", "gas", "lab", "col" }.Concat(AllowedInputVariables).ToArray(); }
    }
    protected override string[] AllowedInputVariables {
      get { return Enumerable.Range(1, 16).Select(i => $"sensor_{i:D2}").ToArray(); }
    }
    protected override int TrainingPartitionStart { get { return 0; } }
    protected override int TrainingPartitionEnd { get { return 40; } }
    protected override int TestPartitionStart { get { return 40; } }
    protected override int TestPartitionEnd { get { return 58; } }
  }
}